export interface DragOptions {
    minHeight: number;
    minY: number;
}
export type LayerPosition = 'bottom' | 'top' | 'left' | 'right' | 'center';
export type DimmedType = 'show' | 'hide' | 'closeable';
export declare const CLOSE_TYPE: {
    readonly DIMMED: "dimmed";
    readonly BACK: "back";
    readonly CUSTOM: "custom";
};
export type CloseType = typeof CLOSE_TYPE[keyof typeof CLOSE_TYPE];
interface CommonOptions<R = undefined> {
    dimmedType: DimmedType;
    transitionDelay: number;
    scrollLockElement: HTMLElement | null;
    onClose?: (value: R | CloseType) => Promise<boolean> | boolean;
}
export interface BottomLayerOptions<R> extends CommonOptions<R> {
    position: Extract<LayerPosition, 'bottom'>;
    draggable: boolean;
    dragOptions: DragOptions;
}
interface OthersLayerOptions<R> extends CommonOptions<R> {
    position: Exclude<LayerPosition, 'bottom'>;
}
export type Options<R> = OthersLayerOptions<R> | BottomLayerOptions<R>;
export interface DefaultOptions extends Omit<OthersLayerOptions<unknown>, 'position'>, Omit<BottomLayerOptions<unknown>, 'position'> {
    position: LayerPosition;
}
export declare const DEFAULT_VALUE: {
    POSITION: LayerPosition;
    DIMMED_TYPE: DimmedType;
    TRANSITION_DELAY: number;
    DRAGGABLE: boolean;
    MIN_HEIGHT: number;
    MIN_Y: number;
    SCROLL_LOCK_ELEMENT: null;
};
export declare const defaultOptions: DefaultOptions;
export {};
